@@ -1,13 +1,14 @@
 import { DataQuery } from '@grafana/schema';
+import { User } from 'app/features/explore/QueryLibrary/types';
 
-import { TemplateQueryTemplate } from '../../api/clients/querylibrary/v0alpha1';
+import { QuerySpec } from '../../api/clients/queries/v1beta1';
 
 export type DataQueryTarget = {
   variables: object; // TODO: Detect variables in #86838
   properties: DataQuery;
 };
 
-export type DataQueryPartialSpec = Partial<TemplateQueryTemplate>;
+export type DataQueryPartialSpec = Partial<QuerySpec>;
 
 export type QueryTemplate = {
   uid: string;
@@ -38,9 +39,3 @@ export type EditQueryTemplateCommand = {
 export type DeleteQueryTemplateCommand = {
   uid: string;
 };
-
-export type User = {
-  uid: string;
-  displayName?: string;
-  avatarUrl?: string;
-};
